==> haskell-yesod-form-1.6.7-153-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-yesod-form.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 yesod-form
version:              1.6.7
visibility:           public
id:                   yesod-form-1.6.7-9jU5IRn4MeyFtXgaD5wfkQ
key:                  yesod-form-1.6.7-9jU5IRn4MeyFtXgaD5wfkQ
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Form handling support for Yesod Web Framework
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-form>.  Third-party packages which you can find useful: <http://hackage.haskell.org/package/yesod-form-richtext yesod-form-richtext> - richtext form fields (currntly it provides only Summernote support).

category:             Web, Yesod
abi:                  6cf0e4ae52a97ec66856f7aa7b578a97
exposed:              True
exposed-modules:
    Yesod.Form Yesod.Form.Bootstrap3 Yesod.Form.Fields
    Yesod.Form.Functions Yesod.Form.I18n.Chinese Yesod.Form.I18n.Czech
    Yesod.Form.I18n.Dutch Yesod.Form.I18n.English
    Yesod.Form.I18n.French Yesod.Form.I18n.German
    Yesod.Form.I18n.Japanese Yesod.Form.I18n.Korean
    Yesod.Form.I18n.Norwegian Yesod.Form.I18n.Portuguese
    Yesod.Form.I18n.Russian Yesod.Form.I18n.Spanish
    Yesod.Form.I18n.Swedish Yesod.Form.Input Yesod.Form.Jquery
    Yesod.Form.MassInput Yesod.Form.Nic Yesod.Form.Types

import-dirs:          /usr/lib/ghc-8.8.3/site-local/yesod-form-1.6.7
library-dirs:         /usr/lib/ghc-8.8.3/site-local/yesod-form-1.6.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/yesod-form-1.6.7
hs-libraries:         HSyesod-form-1.6.7-9jU5IRn4MeyFtXgaD5wfkQ
depends:
    aeson-1.4.7.1-D2ldL4AX1zOJH6OUZhNdCi
    attoparsec-0.13.2.4-E6tYZWwzvMCzu2pmoxmmw base-4.13.0.0
    blaze-builder-0.4.1.0-I5KDHFCu1vgI5dETHU1xLJ
    blaze-html-0.9.1.2-5SOQeKwiKRaDWK8K92Y56k
    blaze-markup-0.8.2.4-JyeEz8woeul42iAs1i68u0
    byteable-0.1.1-8Mf9i6aHWXD4KcleGSFFs bytestring-0.10.10.0
    containers-0.6.2.1 data-default-0.7.1.1-KwmPSgEEmCp4io60ICryCw
    email-validate-2.3.2.12-G07WPxlDIhWH8725HoHzML
    network-uri-2.6.3.0-861BEQnLuNfLHoUhXkzBEV
    persistent-2.10.5.2-7k5tZyGQAoiFdAHRWp60nM
    resourcet-1.2.3-JET6yAzEuesGKlVom96Klf
    shakespeare-2.0.24-CrfvD3goFZXFmSCstZSH2N text-1.2.4.0 time-1.9.3
    transformers-0.5.6.2 wai-3.2.2.1-KKDgPn53NY5E6s1FOKjfNl
    xss-sanitize-0.3.6-HkfhxyHB3aC7y0JBOUIS9j
    yesod-core-1.6.18-6bzzb4mBTLO6CpQe3hSNBI
    yesod-persistent-1.6.0.4-GXJRaYKr5e18gceUcMYP0t

haddock-interfaces:   /usr/share/doc/haskell-yesod-form/html/yesod-form.haddock
haddock-html:         /usr/share/doc/haskell-yesod-form/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-form-1.6.7-154-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-yesod-form.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 yesod-form
version:              1.6.7
visibility:           public
id:                   yesod-form-1.6.7-CObzW2f85FfG6lZKS2faos
key:                  yesod-form-1.6.7-CObzW2f85FfG6lZKS2faos
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Form handling support for Yesod Web Framework
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-form>.  Third-party packages which you can find useful: <http://hackage.haskell.org/package/yesod-form-richtext yesod-form-richtext> - richtext form fields (currntly it provides only Summernote support).

category:             Web, Yesod
abi:                  8c3073b509d331d2342ced5b2125414d
exposed:              True
exposed-modules:
    Yesod.Form Yesod.Form.Bootstrap3 Yesod.Form.Fields
    Yesod.Form.Functions Yesod.Form.I18n.Chinese Yesod.Form.I18n.Czech
    Yesod.Form.I18n.Dutch Yesod.Form.I18n.English
    Yesod.Form.I18n.French Yesod.Form.I18n.German
    Yesod.Form.I18n.Japanese Yesod.Form.I18n.Korean
    Yesod.Form.I18n.Norwegian Yesod.Form.I18n.Portuguese
    Yesod.Form.I18n.Russian Yesod.Form.I18n.Spanish
    Yesod.Form.I18n.Swedish Yesod.Form.Input Yesod.Form.Jquery
    Yesod.Form.MassInput Yesod.Form.Nic Yesod.Form.Types

import-dirs:          /usr/lib/ghc-8.8.3/site-local/yesod-form-1.6.7
library-dirs:         /usr/lib/ghc-8.8.3/site-local/yesod-form-1.6.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/yesod-form-1.6.7
hs-libraries:         HSyesod-form-1.6.7-CObzW2f85FfG6lZKS2faos
depends:
    aeson-1.4.7.1-D2ldL4AX1zOJH6OUZhNdCi
    attoparsec-0.13.2.4-E6tYZWwzvMCzu2pmoxmmw base-4.13.0.0
    blaze-builder-0.4.1.0-I5KDHFCu1vgI5dETHU1xLJ
    blaze-html-0.9.1.2-5SOQeKwiKRaDWK8K92Y56k
    blaze-markup-0.8.2.4-JyeEz8woeul42iAs1i68u0
    byteable-0.1.1-8Mf9i6aHWXD4KcleGSFFs bytestring-0.10.10.0
    containers-0.6.2.1 data-default-0.7.1.1-KwmPSgEEmCp4io60ICryCw
    email-validate-2.3.2.12-G07WPxlDIhWH8725HoHzML
    network-uri-2.6.3.0-23ecXQj6xJbD3Cu3aUxELQ
    persistent-2.10.5.2-7k5tZyGQAoiFdAHRWp60nM
    resourcet-1.2.3-JET6yAzEuesGKlVom96Klf
    shakespeare-2.0.24-CrfvD3goFZXFmSCstZSH2N text-1.2.4.0 time-1.9.3
    transformers-0.5.6.2 wai-3.2.2.1-BvOv88Rv2VP1Z6C8E9byH1
    xss-sanitize-0.3.6-Fg7eRDRR6JC66HZv7rvP83
    yesod-core-1.6.18-7RPQwl1Nb4EKjQx4P8aLzX
    yesod-persistent-1.6.0.4-3i7fxWOGwcx8vaO2fUHgcm

haddock-interfaces:   /usr/share/doc/haskell-yesod-form/html/yesod-form.haddock
haddock-html:         /usr/share/doc/haskell-yesod-form/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
